==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/ms.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Mengurus Parameter Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "mengurus Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Lebar");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Tinggi");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Lebar Imej");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Tinggi Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Memelihara Nisbah Bidang Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "Show Judul");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Susun");
define('MANAGE_GALLERY_DELETE_IMAGE', "Padam Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Jimat Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik &#39;Update&#39; untuk menerbitkan <br /> imej anda dimuat naik.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Semua imej yang telah saiznya dan tetapan telah disimpan.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Terdapat ralat saiz semula imej atau menyimpan tetapan.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imej anda (s) telah dimuat naik.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Terdapat ralat memuat naik imej anda (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fail yang anda cuba memuat naik bukan imej.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fail yang anda cuba memuat naik terlalu besar.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Gelaran ini telah disimpan.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Adakah anda pasti anda mahu memadam imej");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "imej telah dipadam.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Terdapat ralat memotong imej.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Menyimpan parameter dan saiz semula imej, sila tunggu ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Memuat naik, sila tunggu ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Perintah semacam belum disimpan. Adakah anda mahu menyimpan tertib isihan?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Perintah imej jenis telah disimpan.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Ada masalah semasa menyimpan jenis imej kesilapan.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ms.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Mengurus Parameter Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "mengurus Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Lebar");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Tinggi");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Lebar Imej");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Tinggi Image");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Memelihara Nisbah Bidang Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "Show Judul");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Susun");
define('MANAGE_GALLERY_DELETE_IMAGE', "Padam Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Jimat Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik &#39;Update&#39; untuk menerbitkan <br /> imej anda dimuat naik.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Semua imej yang telah saiznya dan tetapan telah disimpan.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Terdapat ralat saiz semula imej atau menyimpan tetapan.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imej anda (s) telah dimuat naik.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Terdapat ralat memuat naik imej anda (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fail yang anda cuba memuat naik bukan imej.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fail yang anda cuba memuat naik terlalu besar.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Gelaran ini telah disimpan.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Adakah anda pasti anda mahu memadam imej");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "imej telah dipadam.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Terdapat ralat memotong imej.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Menyimpan parameter dan saiz semula imej, sila tunggu ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Memuat naik, sila tunggu ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Perintah semacam belum disimpan. Adakah anda mahu menyimpan tertib isihan?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Perintah imej jenis telah disimpan.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Ada masalah semasa menyimpan jenis imej kesilapan.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Fail yang anda cuba muat naik adalah lebih besar daripada &#39;upload_max_filesize&#39; atau setting &#39;post_max_size&#39; PHP. Hubungi pentadbir sistem anda untuk meningkatkan had ini.");
?>
